@@ -8,12 +8,17 @@ __author__ = ["fkiraly"]
 
 import numpy as np
 import pandas as pd
-from sklearn import clone
 
 from sktime.alignment.base import BaseAligner
 from sktime.utils.validation._dependencies import _check_soft_dependencies
 
-_check_soft_dependencies("dtw")
+_check_soft_dependencies(
+    "dtw-python",
+    package_import_alias={"dtw-python": "dtw"},
+    severity="warning",
+    object="AlignerDTW or AlignerDTWfromDist",
+    suppress_import_stdout=True,
+)
 
 
 class AlignerDTW(BaseAligner):
@@ -66,6 +71,13 @@ class AlignerDTW(BaseAligner):
         variable_to_align=None,
     ):
         """Construct instance."""
+        _check_soft_dependencies(
+            "dtw-python",
+            package_import_alias={"dtw-python": "dtw"},
+            severity="error",
+            object=self,
+            suppress_import_stdout=True,
+        )
         super(AlignerDTW, self).__init__()
 
         self.dist_method = dist_method
@@ -232,10 +244,17 @@ class AlignerDTWfromDist(BaseAligner):
         open_end=False,
     ):
         """Construct instance."""
+        _check_soft_dependencies(
+            "dtw-python",
+            package_import_alias={"dtw-python": "dtw"},
+            severity="error",
+            object=self,
+            suppress_import_stdout=True,
+        )
         super(AlignerDTWfromDist, self).__init__()
 
         self.dist_trafo = dist_trafo
-        self.dist_trafo_ = clone(self.dist_trafo)
+        self.dist_trafo_ = self.dist_trafo.clone()
         self.step_pattern = step_pattern
         self.window_type = window_type
         self.open_begin = open_begin
@@ -335,7 +354,7 @@ class AlignerDTWfromDist(BaseAligner):
         return distmat
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Test parameters for AlignerDTWdist."""
         # importing inside to avoid circular dependencies
         from sktime.dists_kernels import ScipyDist
