@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """Base class and type for numba distances."""
-
+__author__ = ["chrisholder", "TonyBagnall"]
 __all__ = [
     "NumbaDistance",
     "DistanceCallable",
@@ -8,10 +8,14 @@ __all__ = [
     "DistancePairwiseCallable",
     "ValidCallableTypes",
     "MetricInfo",
+    "DistanceAlignmentPathCallable",
+    "AlignmentPathReturn",
 ]
 
 from sktime.distances.base._base import MetricInfo, NumbaDistance
 from sktime.distances.base._types import (
+    AlignmentPathReturn,
+    DistanceAlignmentPathCallable,
     DistanceCallable,
     DistanceFactoryCallable,
     DistancePairwiseCallable,
