@@ -8,7 +8,6 @@ __all__ = ["ColumnEnsembleForecaster"]
 
 import numpy as np
 import pandas as pd
-from sklearn.base import clone
 
 from sktime.forecasting.base._base import BaseForecaster
 from sktime.forecasting.base._meta import _HeterogenousEnsembleForecaster
@@ -125,7 +124,7 @@ class ColumnEnsembleForecaster(_HeterogenousEnsembleForecaster):
         self.y_columns = list(y.columns)
 
         for (name, forecaster, index) in forecasters:
-            forecaster_ = clone(forecaster)
+            forecaster_ = forecaster.clone()
 
             forecaster_.fit(y.iloc[:, index], X, fh)
             self.forecasters_.append((name, forecaster_, index))
@@ -196,7 +195,7 @@ class ColumnEnsembleForecaster(_HeterogenousEnsembleForecaster):
         y_pred : pd.Series
             Point predictions
         """
-        return self._by_column("_predict", fh=fh, X=X)
+        return self._by_column("predict", fh=fh, X=X)
 
     def _predict_quantiles(self, fh=None, X=None, alpha=None):
         """Compute/return prediction quantiles for a forecast.
@@ -230,7 +229,12 @@ class ColumnEnsembleForecaster(_HeterogenousEnsembleForecaster):
             Row index is fh. Entries are quantile forecasts, for var in col index,
                 at quantile probability in second-level col index, for each row index.
         """
-        return self._by_column("_predict_quantiles", fh=fh, X=X, alpha=alpha)
+        out = self._by_column("predict_quantiles", fh=fh, X=X, alpha=alpha)
+        if len(out.columns.get_level_values(0).unique()) == 1:
+            out.columns = out.columns.droplevel(level=0)
+        else:
+            out.columns = out.columns.droplevel(level=1)
+        return out
 
     def _predict_interval(self, fh=None, X=None, coverage=None):
         """Compute/return prediction quantiles for a forecast.
@@ -268,7 +272,12 @@ class ColumnEnsembleForecaster(_HeterogenousEnsembleForecaster):
                 Upper/lower interval end forecasts are equivalent to
                 quantile forecasts at alpha = 0.5 - c/2, 0.5 + c/2 for c in coverage.
         """
-        return self._by_column("_predict_interval", fh=fh, X=X, coverage=coverage)
+        out = self._by_column("predict_interval", fh=fh, X=X, coverage=coverage)
+        if len(out.columns.get_level_values(0).unique()) == 1:
+            out.columns = out.columns.droplevel(level=0)
+        else:
+            out.columns = out.columns.droplevel(level=1)
+        return out
 
     def _predict_var(self, fh, X=None, cov=False):
         """Forecast variance at future horizon.
@@ -300,7 +309,7 @@ class ColumnEnsembleForecaster(_HeterogenousEnsembleForecaster):
                 Entries are (co-)variance forecasts, for var in col index, and
                     covariance between time index in row and col.
         """
-        return self._by_column("_predict_var", fh=fh, X=X, cov=cov)
+        return self._by_column("predict_var", fh=fh, X=X, cov=cov)
 
     def get_params(self, deep=True):
         """Get parameters of estimator in `_forecasters`.
@@ -336,7 +345,7 @@ class ColumnEnsembleForecaster(_HeterogenousEnsembleForecaster):
         if isinstance(self.forecasters, BaseForecaster):
             ycols = [str(col) for col in y.columns]
             colrange = range(len(ycols))
-            forecaster_list = [clone(self.forecasters) for _ in colrange]
+            forecaster_list = [self.forecasters.clone() for _ in colrange]
             return list(zip(ycols, forecaster_list, colrange))
 
         if (
@@ -391,7 +400,9 @@ class ColumnEnsembleForecaster(_HeterogenousEnsembleForecaster):
         """
         # imports
         from sktime.forecasting.naive import NaiveForecaster
+        from sktime.forecasting.theta import ThetaForecaster
 
-        FORECASTER = NaiveForecaster()
-        params = {"forecasters": FORECASTER}
-        return params
+        params1 = {"forecasters": NaiveForecaster()}
+        params2 = {"forecasters": ThetaForecaster()}
+
+        return [params1, params2]
