@@ -11,9 +11,11 @@ import pytest
 
 from sktime.forecasting.base import ForecastingHorizon
 from sktime.forecasting.naive import NaiveForecaster
-from sktime.forecasting.tests._config import TEST_OOS_FHS
-from sktime.forecasting.tests._config import TEST_SPS
-from sktime.forecasting.tests._config import TEST_WINDOW_LENGTHS
+from sktime.forecasting.tests._config import (
+    TEST_OOS_FHS,
+    TEST_SPS,
+    TEST_WINDOW_LENGTHS_INT,
+)
 from sktime.utils._testing.forecasting import _assert_correct_pred_time_index
 from sktime.utils.validation.forecasting import check_fh
 
@@ -35,7 +37,7 @@ def test_strategy_last(fh):
 
 
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
-@pytest.mark.parametrize("window_length", TEST_WINDOW_LENGTHS)
+@pytest.mark.parametrize("window_length", TEST_WINDOW_LENGTHS_INT)
 def test_strategy_mean(fh, window_length):
     """Test mean strategy."""
     f = NaiveForecaster(strategy="mean", window_length=window_length)
@@ -69,7 +71,7 @@ def test_strategy_last_seasonal(fh, sp):
 
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
 @pytest.mark.parametrize("sp", TEST_SPS)
-@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS, None])
+@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS_INT, None])
 def test_strategy_mean_seasonal(fh, sp, window_length):
     """Test mean strategy on seasonal data."""
     if (window_length is not None and window_length > sp) or (window_length is None):
@@ -118,7 +120,7 @@ def test_strategy_mean_seasonal_simple(n_seasons, sp):
 
 
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
-@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS, None])
+@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS_INT, None])
 def test_strategy_drift_unit_slope(fh, window_length):
     """Test drift strategy for constant slope 1."""
     if window_length != 1:
@@ -137,7 +139,7 @@ def test_strategy_drift_unit_slope(fh, window_length):
 
 
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
-@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS, None])
+@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS_INT, None])
 def test_strategy_drift_flat_line(fh, window_length):
     """Test flat time series data."""
     if window_length != 1:
@@ -157,7 +159,7 @@ def test_strategy_drift_flat_line(fh, window_length):
 
 
 @pytest.mark.parametrize("fh", TEST_OOS_FHS)
-@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS, None])
+@pytest.mark.parametrize("window_length", [*TEST_WINDOW_LENGTHS_INT, None])
 def test_strategy_drift_window_length(fh, window_length):
     """Test whether window_length is properly working."""
     if window_length != 1:
@@ -180,7 +182,7 @@ def test_strategy_drift_window_length(fh, window_length):
 
 
 @pytest.mark.parametrize("n", [3, 5])
-@pytest.mark.parametrize("window_length", list({4, 5, *TEST_WINDOW_LENGTHS}))
+@pytest.mark.parametrize("window_length", list({4, 5, *TEST_WINDOW_LENGTHS_INT}))
 @pytest.mark.parametrize("sp", list({3, 4, 8, *TEST_SPS}))
 @pytest.mark.parametrize("strategy", ["last", "mean"])
 def test_strategy_mean_and_last_seasonal_additional_combinations(
@@ -197,9 +199,10 @@ def test_strategy_mean_and_last_seasonal_additional_combinations(
     """
     # given <window_length> hours of data with a seasonal periodicity of <sp> hours
     freq = pd.Timedelta("1H")
+    kwargs = dict(closed="left") if pd.__version__ < "1.4.0" else dict(inclusive="left")
     data = pd.Series(
         index=pd.date_range(
-            "2021-06-01 00:00", periods=n * window_length, freq=freq, closed="left"
+            "2021-06-01 00:00", periods=n * window_length, freq=freq, **kwargs
         ),
         data=([float(i) for i in range(1, sp + 1)] * n * window_length)[
             : n * window_length
