@@ -4,7 +4,6 @@
 """Meta-transformers for building composite transformers."""
 
 import pandas as pd
-from sklearn.base import clone
 from sklearn.utils.metaestimators import if_delegate_has_method
 
 from sktime.transformations.base import BaseTransformer
@@ -124,7 +123,7 @@ class OptionalPassthrough(BaseTransformer):
         self: a fitted instance of the estimator
         """
         if not self.passthrough:
-            self.transformer_ = clone(self.transformer)
+            self.transformer_ = self.transformer.clone()
             self.transformer_._fit(X, y)
         return self
 
@@ -171,9 +170,16 @@ class OptionalPassthrough(BaseTransformer):
         return X
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+
+
         Returns
         -------
         params : dict or list of dict, default = {}
@@ -288,7 +294,7 @@ class ColumnwiseTransformer(BaseTransformer):
         # fit by iterating over columns
         self.transformers_ = {}
         for colname in self.columns_:
-            transformer = clone(self.transformer)
+            transformer = self.transformer.clone()
             self.transformers_[colname] = transformer
             self.transformers_[colname].fit(X[colname], y)
         return self
@@ -384,9 +390,16 @@ class ColumnwiseTransformer(BaseTransformer):
         return self
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+
+
         Returns
         -------
         params : dict or list of dict, default = {}
